==> qtjambi-uic-5.15.9-sources.jar: io/qt/uic/ui4/DomColorGroup.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomColorGroup</p>
 */
public class DomColorGroup extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomColorGroup(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColorGroup instance);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.uic.ui4.DomColor> elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.uic.ui4.DomColor> elementColor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.uic.ui4.DomColorRole> elementColorRole(){
        return elementColorRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.uic.ui4.DomColorRole> elementColorRole_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementColor(java.util.Collection<? extends io.qt.uic.ui4.DomColor> a){
        setElementColor_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementColor_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomColor> a);
    
    @io.qt.QtUninvokable
    public final void setElementColorRole(java.util.Collection<? extends io.qt.uic.ui4.DomColorRole> a){
        setElementColorRole_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementColorRole_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomColorRole> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomColorGroup(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-5.15.11-sources.jar: io/qt/uic/ui4/DomColorGroup.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomColorGroup</p>
 */
public class DomColorGroup extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomColorGroup(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomColorGroup instance);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.uic.ui4.DomColor> elementColor(){
        return elementColor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.uic.ui4.DomColor> elementColor_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.uic.ui4.DomColorRole> elementColorRole(){
        return elementColorRole_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.uic.ui4.DomColorRole> elementColorRole_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementColor(java.util.Collection<? extends io.qt.uic.ui4.DomColor> a){
        setElementColor_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementColor_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomColor> a);
    
    @io.qt.QtUninvokable
    public final void setElementColorRole(java.util.Collection<? extends io.qt.uic.ui4.DomColorRole> a){
        setElementColorRole_native_cref_QVector(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementColorRole_native_cref_QVector(long __this__nativeId, java.util.Collection<? extends io.qt.uic.ui4.DomColorRole> a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomColorGroup(QPrivateConstructor p) { super(p); } 
    
}
